summaryrefslogtreecommitdiffstats
path: root/app/multi_animation.h
diff options
context:
space:
mode:
authorsky@chromium.org <sky@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-11-11 00:37:15 +0000
committersky@chromium.org <sky@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-11-11 00:37:15 +0000
commit553aabb40b432ecdc2c289c935ba77874928dfcc (patch)
tree7ecabde66cc28677bc092a715c2a1228cac80ba5 /app/multi_animation.h
parent2ca83cd871de1a2c322a48b80d06f4d3c8bb6923 (diff)
downloadchromium_src-553aabb40b432ecdc2c289c935ba77874928dfcc.zip
chromium_src-553aabb40b432ecdc2c289c935ba77874928dfcc.tar.gz
chromium_src-553aabb40b432ecdc2c289c935ba77874928dfcc.tar.bz2
Makes the instant suggested text autocomplete after 1.3 seconds. There
are a number of parts of this patch that need work, but it should be good enough for us to decide if we want to pursue it. BUG=none TEST=none Review URL: http://codereview.chromium.org/4385001 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@65741 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'app/multi_animation.h')
-rw-r--r--app/multi_animation.h11
1 files changed, 9 insertions, 2 deletions
diff --git a/app/multi_animation.h b/app/multi_animation.h
index 5583c3f..2d4ef2c 100644
--- a/app/multi_animation.h
+++ b/app/multi_animation.h
@@ -13,8 +13,8 @@
// MultiAnimation is an animation that consists of a number of sub animations.
// To create a MultiAnimation pass in the parts, invoke Start() and the delegate
// is notified as the animation progresses. MultiAnimation runs until Stop is
// invoked.
class MultiAnimation : public Animation {
public:
// Defines part of the animation. Each part consists of the following:
@@ -47,6 +47,10 @@ class MultiAnimation : public Animation {
explicit MultiAnimation(const Parts& parts);
virtual ~MultiAnimation();
+ // Sets whether the animation continues after it reaches the end. If true, the
+ // animation runs until explicitly stopped. The default is true.
+ void set_continuous(bool continuous) { continuous_ = continuous; }
+
// Returns the current value. The current value for a MultiAnimation is
// determined from the tween type of the current part.
virtual double GetCurrentValue() const { return current_value_; }
@@ -76,6 +80,9 @@ class MultiAnimation : public Animation {
// Index of the current part.
size_t current_part_index_;
+ // See description above setter.
+ bool continuous_;
+
DISALLOW_COPY_AND_ASSIGN(MultiAnimation);
};
@@ -13,8 +13,8 @@
// MultiAnimation is an animation that consists of a number of sub animations.
// To create a MultiAnimation pass in the parts, invoke Start() and the delegate
-// is notified as the animation progresses. MultiAnimation runs until Stop is
-// invoked.
+// is notified as the animation progresses. By default MultiAnimation runs until
+// Stop is invoked, see |set_continuous()| for details.
class MultiAnimation : public Animation {
public: